@@ -73,6 +73,7 @@ sub spawn {
             _canvas_place_armies           => \&_ongui_canvas_place_armies,
             _canvas_place_armies_initial   => \&_ongui_canvas_place_armies_initial,
             _canvas_motion                 => \&_ongui_canvas_motion,
+            _window_close                  => \&_ongui_window_close,
             # public events
             attack                         => \&_onpub_attack,
             attack_info                    => \&_onpub_attack_info,
@@ -683,13 +684,15 @@ sub _onpriv_start {
     $h->{labels}{defence_1} = $d1;
     $h->{labels}{defence_2} = $d2;
 
+    #-- trap close events
+    $top->protocol( WM_DELETE_WINDOW => $s->postback('_window_close') );
 
     #-- other window
     Games::Risk::GUI::Cards->spawn({parent=>$top});
     Games::Risk::GUI::MoveArmies->spawn({parent=>$top});
 
     #-- say that we're done
-    K->post('risk', 'window_created', 'board');
+    K->yield('load_map', $args->{map});
 }
 
 # -- gui events
@@ -1159,6 +1162,30 @@ sub _ongui_canvas_place_armies_initial {
     K->post('risk', 'initial_armies_placed', $country, 1);
 }
 
+#
+# event: _window_close()
+#
+# called when user wants to close the window.
+#
+sub _ongui_window_close {
+    my $h = $_[HEAP];
+    # FIXME: break circular refs
+
+    # close window
+    $h->{toplevel}->destroy;
+
+    # remove all possible pending events - such as attack vector
+    # cleaning.
+    K->alarm_remove_all;
+
+    # remove aliases & shut down the other windows
+    K->alias_remove('board');
+    K->post('risk', 'shutdown');
+
+    # start another game
+    K->post('startup', 'new_game');
+}
+
 
 1;
 
